// Polyfill Object.assign for legacy browsers.
// https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/Object/assign

if (typeof Object.assign !== 'function') {
  (function () {
    Object.assign = function (target) {
      'use strict'
      var output
      var index
      var source
      var nextKey
      if (target === undefined || target === null) {
        throw new TypeError('Cannot convert undefined or null to object')
      }
      output = Object(target)
      for (index = 1; index < arguments.length; index++) {
        source = arguments[index]
        if (source !== undefined && source !== null) {
          for (nextKey in source) {
            if (source.hasOwnProperty(nextKey)) {
              output[nextKey] = source[nextKey]
            }
          }
        }
      }
      return output
    }
  }())
}
